pub struct WriteStorageObject {
pub collection: String,
pub key: String,
pub value: String,
pub version: String,
pub permission_read: Option<i32>,
pub permission_write: Option<i32>,
}Fields
collection: Stringkey: Stringvalue: Stringversion: Stringpermission_read: Option<i32>permission_write: Option<i32>Trait Implementations
Sourceimpl Clone for WriteStorageObject
impl Clone for WriteStorageObject
Sourcefn clone(&self) -> WriteStorageObject
fn clone(&self) -> WriteStorageObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WriteStorageObject
impl Debug for WriteStorageObject
Sourceimpl Default for WriteStorageObject
impl Default for WriteStorageObject
Sourceimpl Message for WriteStorageObject
impl Message for WriteStorageObject
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WriteStorageObject
impl PartialEq for WriteStorageObject
impl StructuralPartialEq for WriteStorageObject